Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Elastic Container Registry.

Actions, resources, and condition keys for Amazon Elastic Container Registry - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Elastic Container Registry

Amazon Elastic Container Registry (service prefix: `ecr` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Elastic Container Registry
- Resource types defined by Amazon Elastic Container Registry
- Condition keys for Amazon Elastic Container Registry

## Actions defined by Amazon Elastic Container Registry

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
BatchCheckLayerAvailability | Grants permission to check the availability of multiple image layers in a specified registry and repository | Read | repository* |  |
BatchDeleteImage | Grants permission to delete a list of specified images within a specified repository | Write | repository* |  |
BatchGetImage | Grants permission to get detailed information for specified images within a specified repository | Read | repository* |  |
BatchGetRepositoryScanningConfiguration | Grants permission to retrieve repository scanning configuration for a list of repositories | Read | repository* |  |
BatchImportUpstreamImage | Grants permission to retrieve the image from the upstream registry and import it to your private registry | Write |  |  |
CompleteLayerUpload | Grants permission to inform Amazon ECR that the image layer upload for a specified registry, repository name, and upload ID, has completed | Write | repository* |  |
CreatePullThroughCacheRule | Grants permission to create new pull-through cache rule | Write |  |  | iam:CreateServiceLinkedRole
CreateRepository | Grants permission to create an image repository | Write |  | aws:RequestTag/${TagKey} aws:TagKeys | ecr:TagResource
DeleteLifecyclePolicy | Grants permission to delete the specified lifecycle policy | Write | repository* |  |
DeletePullThroughCacheRule | Grants permission to delete the pull-through cache rule | Write |  |  |
DeleteRegistryPolicy | Grants permission to delete the registry policy | Permissions management |  |  |
DeleteRepository | Grants permission to delete an existing image repository | Write | repository* |  |
DeleteRepositoryPolicy | Grants permission to delete the repository policy from a specified repository | Permissions management | repository* |  |
DescribeImageReplicationStatus | Grants permission to retrieve replication status about an image in a registry, including failure reason if replication fails | Read | repository* |  |
DescribeImageScanFindings | Grants permission to describe the image scan findings for the specified image | Read | repository* |  |
DescribeImages | Grants permission to get metadata about the images in a repository, including image size, image tags, and creation date | List | repository* |  |
DescribePullThroughCacheRules | Grants permission to describe the pull-through cache rules | List |  |  |
DescribeRegistry | Grants permission to describe the registry settings | Read |  |  |
DescribeRepositories | Grants permission to describe image repositories in a registry | Read | repository |  |
GetAuthorizationToken | Grants permission to retrieve a token that is valid for a specified registry for 12 hours | Read |  |  |
GetDownloadUrlForLayer | Grants permission to retrieve the download URL corresponding to an image layer | Read | repository* |  |
GetLifecyclePolicy | Grants permission to retrieve the specified lifecycle policy | Read | repository* |  |
GetLifecyclePolicyPreview | Grants permission to retrieve the results of the specified lifecycle policy preview request | Read | repository* |  |
GetRegistryPolicy | Grants permission to retrieve the registry policy | Read |  |  |
GetRegistryScanningConfiguration | Grants permission to retrieve registry scanning configuration | Read |  |  |
GetRepositoryPolicy | Grants permission to retrieve the repository policy for a specified repository | Read | repository* |  |
InitiateLayerUpload | Grants permission to notify Amazon ECR that you intend to upload an image layer | Write | repository* |  |
ListImages | Grants permission to list all the image IDs for a given repository | List | repository* |  |
ListTagsForResource | Grants permission to list the tags for an Amazon ECR resource | Read | repository* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
PutImage | Grants permission to create or update the image manifest associated with an image | Write | repository* |  |
PutImageScanningConfiguration | Grants permission to update the image scanning configuration for a repository | Write | repository* |  |
PutImageTagMutability | Grants permission to update the image tag mutability settings for a repository | Write | repository* |  |
PutLifecyclePolicy | Grants permission to create or update a lifecycle policy | Write | repository* |  |
PutRegistryPolicy | Grants permission to update the registry policy | Permissions management |  |  |
PutRegistryScanningConfiguration | Grants permission to update registry scanning configuration | Write |  |  |
PutReplicationConfiguration | Grants permission to update the replication configuration for the registry | Write |  |  |
ReplicateImage [permission only] | Grants permission to replicate images to the destination registry | Write | repository* |  |
SetRepositoryPolicy | Grants permission to apply a repository policy on a specified repository to control access permissions | Permissions management | repository* |  |
StartImageScan | Grants permission to start an image scan | Write | repository* |  |
StartLifecyclePolicyPreview | Grants permission to start a preview of the specified lifecycle policy | Write | repository* |  |
TagResource | Grants permission to tag an Amazon ECR resource | Tagging | repository* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to untag an Amazon ECR resource | Tagging | repository* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UploadLayerPart | Grants permission to upload an image layer part to Amazon ECR | Write | repository* |  |

## Resource types defined by Amazon Elastic Container Registry

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
repository | `arn:$ { Partition}:ecr:$ { Region}:$ { Account}:repository/$ { RepositoryName}` | aws:ResourceTag/${TagKey} ecr:ResourceTag/${TagKey}

## Condition keys for Amazon Elastic Container Registry

Amazon Elastic Container Registry defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters access by tag-value associated with the resource | String
aws:TagKeys | Filters access by the presence of mandatory tags in the request | ArrayOfString
ecr:ResourceTag/${TagKey} | Filters access by tag-value associated with the resource | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.